AGW Logo

svn SVN Revision 68350 For floatspin

This file contains the SVN revision history for floatspin, at revision 68350.

Available information include commit date, the name of the committer, the file size, the SVN log messages and a diff from the previous version (if available).


file_info File Information

  • Commit Date: 25-Feb-2009 23:46:10 UTC
  • Committer: AG
  • File Size: 52162 byte(s)

svn_log Log Messages

The following log message was entered by the committer:

Bind the mouse wheel events to the spinbutton and textctrl instead of to FloatSpin


svn_diff Diff To Previous Version (65774)

Version SVN diff:

--- wxPython/3rdParty/AGW/agw/floatspin.py  2010/10/05 23:38:27     65774
+++ wxPython/3rdParty/AGW/agw/floatspin.py  2011/07/23 23:26:40     68350
@@ -3,7 +3,7 @@
# Python Code By:
#
# Andrea Gavana, @ 16 Nov 2005
# Latest Revision: 21 Sep 2010, 23.00 GMT
#
#
# TODO List/Caveats
@@ -101,7 +101,7 @@

FloatSpin control is distributed under the wxPython license.

-Latest revision: Andrea Gavana @ 21 Sep 2010, 23.00 GMT
+Latest revision: Andrea Gavana @ 22 Jul 2011, 21.00 GMT

Version 0.9

@@ -459,9 +459,11 @@
self._spinbutton.Bind(wx.EVT_LEFT_DOWN, self.OnSpinMouseDown)

self._textctrl.Bind(wx.EVT_TEXT_ENTER, self.OnTextEnter)
+        self._textctrl.Bind(wx.EVT_MOUSEWHEEL, self.OnMouseWheel)
+        self._spinbutton.Bind(wx.EVT_MOUSEWHEEL, self.OnMouseWheel)
+
self.Bind(wx.EVT_SET_FOCUS, self.OnFocus)
self.Bind(wx.EVT_KILL_FOCUS, self.OnKillFocus)
-        self.Bind(wx.EVT_MOUSEWHEEL, self.OnMouseWheel)
self.Bind(wx.EVT_SIZE, self.OnSize)

# start Philip Semanchuk move
@@ -3,7 +3,7 @@
#
# Andrea Gavana, @ 16 Nov 2005
-# Latest Revision: 21 Sep 2010, 23.00 GMT
+# Latest Revision: 22 Jul 2011, 21.00 GMT
#
#
Tree

Table Of Contents

Previous topic

floatspin functions

Next topic

SVN Revision 68881 For floatspin